@@ -29,12 +29,12 @@
 #include <Lum/Dlg/Msg.h>
 
 #include <Lum/Model/Action.h>
-#include <Lum/Model/Integer.h>
+#include <Lum/Model/Number.h>
 
-#include <Lum/OS/Main.h>
-
-#include <Lum/OS/Manager/Repository.h>
+#include <Lum/Manager/Display.h>
+#include <Lum/Manager/FileSystem.h>
 
+#include <Lum/Application.h>
 #include <Lum/Button.h>
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
@@ -159,7 +159,7 @@ public:
 
   void AllowScreenBlanking(bool allow)
   {
-    Lum::OS::Manager::DisplayManager *displayManager=Lum::OS::Manager::repository->GetDisplayManager();
+    Lum::Manager::Display *displayManager=Lum::Manager::Display::Instance();
 
     if (displayManager!=NULL) {
       displayManager->AllowScreenBlanking(allow);
@@ -379,13 +379,13 @@ public:
 
 };
 
-class Main : public Lum::OS::MainDialog<MainDialog>
+class Main : public Lum::GUIApplication<MainDialog>
 {
 public:
-  bool Prepare()
+  bool Initialize()
   {
 #if defined(APP_DATADIR)
-    Lum::Base::Path::SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
+    Lum::Manager::FileSystem::Instance()->SetApplicationDataDir(Lum::Base::StringToWString(APP_DATADIR));
 #endif
 
     info.SetProgram(Lum::Base::StringToWString(PACKAGE_NAME));
@@ -396,14 +396,14 @@ public:
     info.SetCopyright(L"(c) 2007, Tim Teulings");
     info.SetLicense(L"GNU Public License");
 
-    return Lum::OS::MainDialog<MainDialog>::Prepare();
+    return Lum::GUIApplication<MainDialog>::Initialize();
   }
 
   void Cleanup()
   {
     FreeConfig();
 
-    Lum::OS::MainDialog<MainDialog>::Cleanup();
+    Lum::GUIApplication<MainDialog>::Cleanup();
   }
 };
 
