@@ -34,9 +34,43 @@
 
 #include "TeeEdit.h"
 
+class TeasModelPainter : public Lum::TableCellPainter
+{
+public:
+  void Draw(Lum::OS::DrawInfo* draw,
+            int x, int y, size_t width, size_t height) const
+  {
+    const Tea tea=dynamic_cast<const TeasModel*>(GetModel())->GetEntry(GetRow());
+
+    //
+    // Name of Tea
+    //
+
+    DrawStringLeftAligned(draw,
+                          x,y,width,height,
+                          tea.name);
+
+    //
+    //
+    // Time of tea
+
+    std::wstring time=Lum::Base::NumberToWString(tea.minutes);
+
+    time.append(L":");
+    if (tea.seconds<10) {
+      time.append(L"0");
+    }
+    time.append(Lum::Base::NumberToWString(tea.seconds));
+
+    DrawStringRightAligned(draw,
+                           x,y,width,height,
+                           time);
+  }
+};
+
 Selector::Selector(Lum::Model::SizeT *seconds)
  : seconds(seconds),
-   list(new TeasModel(teas,new TeasDataProvider())),
+   list(new TeasModel(teas)),
    selection(new Lum::Model::SingleLineSelection()),
    addAction(new Lum::Model::Action()),
    editAction(new Lum::Model::Action()),
@@ -84,12 +118,13 @@ Lum::Object* Selector::GetContent()
   table=new Lum::Table();
   table->SetFlex(true,true);
   table->SetShowHeader(false);
-  //table->GetTableView()->SetAutoFitColumns(true);
+  table->GetTableView()->SetAutoFitColumns(true);
   table->GetTableView()->SetAutoHSize(true);
   table->SetModel(list);
   table->SetHeaderModel(headerModel);
   table->SetSelection(selection);
   table->SetDoubleClickAction(okAction);
+  table->SetPainter(new TeasModelPainter());
   horiz->Add(table);
 
   horiz->AddSpace();
